/******************************************************************************
* Copyright (c) 2020 Xilinx, Inc. All rights reserved.
* SPDX-License-Identifier: MIT
******************************************************************************/

/*****************************************************************************/
/**
* @file xbir_qspi.h
*
* This is the qspi header file which contains definitions for the qspi.
*
*
* <pre>
* MODIFICATION HISTORY:
*
* Ver   Who    Date       Changes
* ----- ---- ---------- -------------------------------------------------------
* 1.00  bsv   07/02/20   First release
*
* </pre>
*
******************************************************************************/

#ifndef XBIR_QSPI_H
#define XBIR_QSPI_H

#ifdef __cplusplus
extern "C" {
#endif

/***************************** Include Files *********************************/
#include "xqspipsu.h"
#include "xbir_qspi_hw.h"

/************************** Constant Definitions *****************************/
#define	XBIR_QSPI_CONFIG_FAILED			(0x20U)
#define	XBIR_QSPI_CONFIG_INIT_FAILED		(0x21U)
#define	XBIR_ERROR_QSPI_READ			(0x22U)
#define	XBIR_QSPI_4BYTE_ENETER_ERROR		(0x23U)
#define	XBIR_ERROR_INVALID_QSPI_CONNECTION	(0x24U)
#define	XBIR_ERROR_QSPI_LENGTH			(0x25U)
#define	XBIR_POLLED_TRANSFER_FAILED		(0x26U)
#define	XBIR_ERROR_QSPI_MANUAL_START		(0x27U)
#define	XBIR_ERROR_QSPI_PRESCALER_CLK		(0x28U)
#define	XBIR_ERROR_UNSUPPORTED_QSPI_CONN_MODE	(0x29U)
#define XBIR_ERROR_UNSUPPORTED_QSPI_VENDOR	(0x30U)

/**************************** Type Definitions *******************************/
struct XbirContext;
typedef struct XbirContext XbirContext;

struct XbirContext {
    XQspiPsu tQspiPsuInstance;

    /*
     * Logical sizes for combined flash
     */
    u32 qSectorSize;
    u32 qNumSectors;
    u32 qPageSize;
    u32 qSubsectorSize; /* Hardwired, not in table */

    u32 RdCmd;
    int StatusCmd;
    /*
     * This is per-flash-chip
     */
    Xbir_QspiFlashInfo FlashInfo;
    u8 FsrFlag;
    u8 MacronixFlash;
};

/***************** Macros (Inline Functions) Definitions *********************/

/************************** Function Prototypes ******************************/
int Xbir_QspiInit (XbirContext* pContext,XQspiPsu_Config* pQspiConfig,uint32_t qPrescaler);
int Xbir_QspiRead (XbirContext* pContext,u32 SrcAddr, u8 *DestAddr, u32 Length);
int Xbir_QspiWrite(XbirContext* pContext,u32 Addr, const u8 *WrBuff, u32 Len);
int Xbir_QspiFlashErase(XbirContext* pContext,u32 Address, u32 Length);
u16 Xbir_QspiGetPageSize(XbirContext* pContext);
int FlashInit(XbirContext* pContext,XQspiPsu_Config* pQspiPsuConfig,uint32_t qPrescaler);
int FlashErase(XbirContext* pContext,uint32_t qStart,uint32_t qSize);
int FlashRead(XbirContext* pContext,uint32_t qStart,uint32_t qSize,uint8_t* pbDst);
int FlashWrite(XbirContext* pContext, uint32_t qStart, uint32_t qSize,const uint8_t *pbSrc);

#ifdef __cplusplus
}
#endif

#endif  /* XBIR_QSPI_H */
