#! /usr/bin/env bash
#
# Copyright 2021 Xilinx, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

set -x
set -e
TOP=..
if [[ "X$1" = "X" ]]; then
    echo "Usage: $0 DESIGN"
    exit 1
fi
DESIGN=$1
if [ -d "${DESIGN}" ]; then
    DESIGN_DIR="${DESIGN}"
else
    DESIGN_DIR="${TOP}/designs/${DESIGN}"
fi
source ./decode_design_dir.sh ${DESIGN_DIR}

pushd $TOP/x86_app
    ./clean.sh
    ./do.sh
popd
pushd $TOP/sim_images
    ./clean.sh
    ./do.sh
popd

source /tools/Xilinx/Vivado/2020.3/settings64.sh

./clean_r5.sh "${DESIGN_DIR}" "${TOP}/r5_app"
./do_r5.sh "${DESIGN_DIR}" "${TOP}/r5_app"

./clean_r5.sh "${DESIGN_DIR}" "${TOP}/r5_multiboot_app"
./do_r5.sh "${DESIGN_DIR}" "${TOP}/r5_multiboot_app"

./clean_r5.sh "${DESIGN_DIR}" "${TOP}/r5_golden_app"
./do_r5.sh "${DESIGN_DIR}" "${TOP}/r5_golden_app"

# Package single app, for either core
./package_boot.sh "${DESIGN_DIR}" "${TOP}/r5_app"
./package_boot.sh "${DESIGN_DIR}" "${TOP}/r5_multiboot_app"
./package_boot.sh "${DESIGN_DIR}" "${TOP}/r5_golden_app"

# Create binary distribution
./package_binaries.sh ${DESIGN}

# Create test tarball
./package_boardtest.sh ${DESIGN}

#./clean_r5.sh ${TOP}/designs/${DESIGN} ${TOP}/r5_hello_1
#./do_r5.sh ${TOP}/designs/${DESIGN} ${TOP}/r5_hello_1

# Package two apps, one for r5-0 and one for r5-1
#./package_boot.sh ${TOP}/designs/${DESIGN} ${TOP}/r5_golden_app ${TOP}/r5_hello_1
