/*
 * Copyright 2021 Xilinx, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef X86_APP_H__
#define X86_APP_H__

#define _GNU_SOURCE

#include <common.h>
#include <r5_pef.h>
#include <x86_util.h>
#include <x86_csv.h>
#include <x86_r5_sim.h>
#include <x86_r5_device.h>
#include <x86_device.h>
#include <x86_app.h>
#include <x86_r5_comms.h>
#include <x86_devinfo.h>
#include <x86_program.h>

extern void CloseSys(Sys* pSys);
extern void Help(Sys* pSys);

struct CmdInfo;
typedef struct CmdInfo CmdInfo;

struct BDF;
typedef struct BDF BDF;

struct CmdInfo {
    COMMAND eCommand;
    const char* pcCmd;
    const char* pcHelp;
};

#define BDF_SYSFILE_BYTES   256
struct BDF {
    uint32_t qDomain;
    uint32_t qBoard;
    uint32_t qDevice;
    uint32_t qFunction;
    char pcEnableFile[BDF_SYSFILE_BYTES];
    char pcResourceFile[BDF_SYSFILE_BYTES];
    char* pcUioFile;
};

struct Sys {
    /*
     * base part of argv[0], for logs/prompt
     */
    const char* pcProgName;

    /*
     * Input arguments
     */
    bool yLogger;
    bool yVerbose;
    bool yExtra;
    const char* pcImagesPath;
    const char* pcImagesCsv;
    const char* pcBoardsCsv;
    char* pcDevice;
    const char* pcCommandFile;

    uint32_t qImagesPathLen;

    /*
     * Parts of pcDevice, current board
     */
    const char* pcBoardType;
    const char* pcBDF;
    BDF tBDF;

    BoardInfo *pBI;
    uint8_t* pbReserved;            /* First 3 subsectors of reserved block */
    ReservedBlockEntry* ppRBE[3];   /* Pointers into pbReserved */
    uint32_t qMultibootChar;        /* Set by sim argument or board state */

    /*
     * Command file handle and current line
     */
    FILE* pCommandFile;
    int iCommandLine;

    /*
     * Csv files as linked lists
     */
    ListHead tImagesCsvListHead;
    ListHead tBoardsCsvListHead;

    /*
     * Stop interpreter loop if true
     * Set by exit command
     */
    bool yStop;

    /*
     * CommArea mapping
     */
    MessageArea* pMA;

    /*
     * AuxArea mapping
     */
    AuxArea* pAA;

    /*
     * R5 simulator specific variables
     */
    const char* pcSimFlash;

    /*
     * Device data (sim or non-sim)
     */
    void* pDevData;
};

#endif  /* X86_APP_H__ */
